# Source Term Exclusion

## Description

Mondo imports terms from multiple sources (e.g. ICD10CM, Orphanet,...). These sources contain terms which’s concept is out of scope for Mondo, and therefore should not be imported. These excluded terms are recorded in “exclusion lists”.

These exclusion lists include :
  - term_ID: identifier of the term at the source
  - term_label: term label at the source
  - exclusion_reason: reason(s) for excluding the term in Mondo. The exclusion reason should a code from the table below
  - exclude_children: true or false, this field indicates whether the children of this term should also be excluded from Mondo. This field is only applicable when the source of the term is an ontology.

Exclusion lists are in the .tsv format and maintained in this folder: `mondo-ingest/src/ontology/config/`. Each source has its own term exclusion list(e.g `mondo-ingest/src/ontology/config/icd10cm_exclusions.tsv`)

**Updating the source exclusion list:**
Curators should update the exclusion list by updating the .tsv file. For example, the excluded ICD10CM terms list should be done by updating the following file: `mondo-ingest/src/ontology/config/icd10cm_exclusions.tsv`
Note that these updates should be associated with a PR in Github, such that we are able to review changes history.


## Exclusion Reasons
_This document is a work in progress._ Noted below are reasons for excluding external ontology or terminology terms from Mondo. See enum file [here](https://github.com/monarch-initiative/mondo/blob/master/src/schema/mondo.yaml). The dashes in column 1 are meant to indicate the code is a subtype of the code above.

| codes                                       | code name                                                | Definitions                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | Notes                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | Examples                                                                                                                                                                                                                                                                                                                     | IF source is an ontology, the children of this term should also be excluded |
|---------------------------------------------|----------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------|
| MONDO:excludeNonDisease                     | not a disease                                            | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | This blanket exclusion code is used in cases  when the term represents a non disease concept for which a more precise code is unavailable, and/or we did not have the resources to determine which more specific exclusion code should be used.                                                                                                                                                                                                                                                                             |                                                                                                                                                                                                                                                                                                                              |                                     TRUE                                    |
| --- MONDO:excludePhenotype                  | phenotype                                                | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents observable characteristics of an individual that is the product of interactions between genes and the environment.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | This code includes concepts representing "features", "symptoms", and "clinical finding" describing results of clinical, laboratory, or molecular examination.                                                                                                                                                                                                                                                                                                                                                               | ICD10CM:E16.3 - Increased secretion of glucagon ICD10CM:R70-R79 - Abnormal findings on examination of blood, without diagnosis ICD10CM:R25-R29 - Symptoms and signs involving the nervous and musculoskeletal systems ICD10CM:Z68.53 - Body mass index [BMI] pediatric, 85th percentile to less than 95th percentile for age |                                     TRUE                                    |
| --- MONDO:excludeTrait                      | trait                                                    | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents a characteristic of an individual.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | ICD10CM:Z67-Z67 - blood type ICD10CM:Z68-68 - Body Mass Index                                                                                                                                                                                                                                                                |                                     TRUE                                    |
| --- MONDO:excludeBiologicalProcess          | biological process                                       | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and describes a biological process. [From GO:0008150: A biological process represents a specific objective that the organism is genetically programmed to achieve. Biological processes are often described by their outcome or ending state, e.g., the biological process of cell division results in the creation of two daughter cells (a divided cell) from a single parent cell. A biological process is accomplished by a particular set of molecular functions carried out by specific gene products (or macromolecular complexes), often in a highly regulated manner and in a particular temporal sequence.] | - This code applies for terms describing a biological process occuring "normally" (e.g.  ICD10CM:O00-O9A - Pregnancy, childbirth and the puerperium) - For cases where the biological process occurs "abnormally", MONDO:excludePhenotype should be used (e.g. MONDO:0007816 - obsolete immune suppression) - For cases where the biological process could be occuring "normally" or "abnormally", this code, MONDO:excludeBiologicalProcess, can be used (e.g. MONDO:0006185 - obsolete ductal or ductular proliferation)  | ICD10CM:O00-O9A - Pregnancy, childbirth and the puerperium                                                                                                                                                                                                                                                                   |                                     TRUE                                    |
| --- MONDO:excludeBiomarker                  | biomarker                                                | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents measurable indicator of some biological state or condition, such as disease status.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | When the term concept represents the biomarker status, one might consider using MONDO:excludePhenotype (e.g. ICD10CM:Z17.0 - Estrogen receptor positive status [ER+]), or MONDO:excludeRiskFactor (e.g. ICD10CM:Z15.01 - Genetic susceptibility to malignant neoplasm of breast; synonym: Brca1 gene mutation positive).                                                                                                                                                                                                    | ICD10CM:Z17-Z17 - Estrogen receptor status                                                                                                                                                                                                                                                                                   |                                     TRUE                                    |
| --- MONDO:excludeCausalAgents               | disease causing agents                                   | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents agents, such as bacteria or other pathogens, that cause disease.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | ICD10CM:B95-B97 - Bacterial and viral infectious agents ICD10CM:B95.0 - Streptococcus, group A, as the cause of diseases classified elsewhere                                                                                                                                                                                |                                     TRUE                                    |
| --- MONDO:excludeGene                       | gene                                                     | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents a gene or protein.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | MONDO:0007578 - obsolete esterase B MONDO:0011763 - obsolete T-box 24                                                                                                                                                                                                                                                        |                                     TRUE                                    |
| --- MONDO:excludeExternalFactor             | external factor                                          | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents factors and/or actions that influence health status and might (or might not) be the cause of a disease.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | This code should be used when the concept is not clearly a procedure, an event, or a medical action, or is a mix of these.                                                                                                                                                                                                                                                                                                                                                                                                  | ICD10CM:Z00-Z99	- Factors influencing health status and contact with health services                                                                                                                                                                                                                                          |                                     TRUE                                    |
| ------ MONDO:excludeCondition               | condition                                                | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents a condition possibly leading to disease.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | ICD10CM:P80-P83 - Conditions involving the integument and temperature regulation of newborn                                                                                                                                                                                                                                  |                                     TRUE                                    |
| ------ MONDO:excludeMedicalAction           | medical action                                           | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents a clinically prescribed procedure, therapy, intervention, or recommendation.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | ICD10CM:O30-O48 - Maternal care related to the fetus and amniotic cavity and possible delivery problems ICD10CM:O09-O09 - Supervision of high risk pregnancy                                                                                                                                                                 |                                     TRUE                                    |
| ------ MONDO:excludeEvent                   | event                                                    | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represent occurrences; these could result in injury and/or its effect, or represent periods in a disease.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | This code excludes all procedures and interventions; these should be excluded using the code MONDO:excludeMedicalAction.                                                                                                                                                                                                                                                                                                                                                                                                    | ICD10CM:Y62-Y69 - Misadventures to patients during surgical and medical care Orphanet:391655 - Off-periods in Parkinson disease not responding to oral treatment ICD10CM:V98.3 - Accident to, on or involving ski lift                                                                                                       |                                     TRUE                                    |
| --- MONDO:excludePopulation                 | population                                               | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents individuals or individual populations.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | ICD10CM:V60-V69 - Occupant of heavy transport vehicle injured in transport accident ICD10CM:P50 - Newborn affected by intrauterine (fetal) blood loss                                                                                                                                                                        |                                     TRUE                                    |
| --- MONDO:excludeRiskFactor                 | risk factor                                              | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents a condition or a genetic carrier that increases the chance of developing a disease.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | ICD10CM:Z15.01 - Genetic susceptibility to malignant neoplasm of breast                                                                                                                                                                                                                                                      |                                     TRUE                                    |
| --- MONDO:excludeComplication               | complication                                             | Code used when the term is excluded from Mondo based on the fact that the term's concept is not a disease and represents a complication to an external procedure (e.g surgery) or events (e.g birth).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | One needs to be careful to not confuse actual "diseases" resulting from an event (e.g. injury, disease resulting from infection, or viral sequela). In these cases, the representation of the concept in Mondo might be reasonable.                                                                                                                                                                                                                                                                                         | ICD10CM:E36-E36 - Intraoperative complications of endocrine system Orphanet:90053 - Complications after hematopoietic stem cell transplantation                                                                                                                                                                              |                                     TRUE                                    |
|                                             |                                                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |                                                                                                                                                                                                                                                                                                                              |                                                                             |
| MONDO:excludeHistoricalDisease              | historical disease                                       | Code used when the term is excluded from Mondo based on the fact that the term's concept is no longer considered a disease due to lack of supporting evidence.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | MONDO:0000238 - obsolete pestis minor MONDO:0009827 - obsolete pachyonychia congenita, autosomal recessive                                                                                                                                                                                                                   |                                    FALSE                                    |
|                                             |                                                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |                                                                                                                                                                                                                                                                                                                              |                                                                             |
| MONDO:excludeGrouping                       | grouping                                                 | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases in a way that is not supported in Mondo.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | This blanket exclusion code is used in cases when the term represents a grouping term for which no more precise code is available, and/or we did not have the resources to determine which more specific exclusion code should be used.                                                                                                                                                                                                                                                                                     | MONDO:0020051 - obsolete total autosomal trisomy MONDO:0019843 - obsolete pituitary hormone deficiency secondary to a granulomatous disease                                                                                                                                                                                  |                                    FALSE                                    |
| --- MONDO:excludeGroupingPhenotype          | grouping - based on shared phenotype/feature             | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on shared phenotypes and/or features, which is a disease classification/grouping not supported in Mondo.                                                                                                                                                                                                                                                                                                                                                                                                                                                                            | When requested by the expert community, terms grouping diseases based on phenotype/feature could be included into Mondo. However (1) use case(s) for this request is(are) required (since other avenues, such as query through disease annotations, might be more appropriate solutions), (2) commitment by the requesters to maintain the list of grouped diseases (ie children of the grouping term) is requested in order to ensure that this ontology branch is correct and complete.                                   | Orphanet:567558 - Non-genetic systemic disease with glomerulopathy as a major feature Orphanet:567562 - Disorder with multisystemic involvement and glomerulopathy                                                                                                                                                           |                                    FALSE                                    |
| --- MONDO:excludeGroupingMorpho             | grouping - based on morphology                           | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on affected morphological structure, and this grouping was reported to be uninformative and deemed unnecessary (based on Harrison's Principles of Internal Medicine).                                                                                                                                                                                                                                                                                                                                                                                                               | https://doi.org/10.5281/zenodo.5273598                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | MONDO_0015163 - obsolete primary glomerular disease MONDO_0021145 - obsolete disorder of genitourinary system                                                                                                                                                                                                                |                                    FALSE                                    |
| --- MONDO:excludeGroupingOrigin             | grouping based on disease origin                         | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on their shared origin.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | This blanket exclusion code is used in cases when the term represents a grouping term based on the disease origin for which no more precise code is available, and/or we did not have the resources to determine which more specific exclusion code should be used.                                                                                                                                                                                                                                                         | Orphanet:542323 - CAR T cell therapy-associated cytokine release syndrome MONDO:0024147 -  obsolete Pierre Robin syndrome associated with a chromosomal anomaly MONDO:0019833 - obsolete pituitary hormone deficiency from tumoral origin                                                                                    |                                    FALSE                                    |
| ------ MONDO:excludeGroupingOriginGenetic   | grouping based on genetic origin                         | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on their shared genetic origin.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | - For cases in which the grouping term is based on the defective gene, GroupingOriginMolecular should be used. - In some cases, it might be appropriate to include the term as a narrow concept of a Mondo term (e.g. Orphanet:206634-Genetic skeletal muscle disease _MONDO:mondoIsBroaderThanSource_ MONDO:0020120-skeletal muscle disease)                                                                                                                                                                               | MONDO:0018787 - obsolete genetic cerebral small vessel disease MONDO:0019117 - obsolete genetic nervous system disorder                                                                                                                                                                                                      |                                    FALSE                                    |
| ------ MONDO:excludeGroupingOriginMolecular | grouping based on molecular origin                       | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on defect in a same gene/protein/protein complex.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | When requested by the expert community, terms grouping diseases based on the defective gene/protein/protein complex could be included into Mondo. However (1) use case(s) for this request is(are) required (since other avenues, such as query through disease annotations, might be more appropriate solutions), (2) commitment by the requesters to maintain the list of grouped diseases (ie children of the grouping term) is requested in order to ensure that this ontology branch is correct and complete.          | Orphanet:603699 - KLHL7-related disorder Orphanet:98748 - Neurological channelopathy of the central nervous system due to a genetic acetylcholine receptor defect Orphanet:207090 - Qualitative or quantitative defects of collagen 6                                                                                        |                                    FALSE                                    |
| ------ MONDO:excludeGroupingOriginProcess   | grouping based on process origin                         | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on defect in a same biological process.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | When requested by the expert community, terms grouping diseases based on the defective biological process could be included into Mondo. However (1) use case(s) for this request is(are) required (since other avenues, such as query through disease annotations, might be more appropriate solutions), (2) commitment by the requesters to maintain the list of grouped diseases (ie children of the grouping term) is requested in order to ensure that this ontology branch is correct and complete.                    | MONDO:0006600 - obsolete pigmentation disease MONDO:0021016 - obsolete channelopathy                                                                                                                                                                                                                                         |                                    FALSE                                    |
| ------ MONDO:excludeGroupingModifier        | grouping based on clinical modifier                      | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on shared modifier (e.g. symptomatic, severe, moderate,...).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | - Terms excluded with this code represent grouping terms; actual diseases including the modifier should not be excluded (e.g. Orphanet:465508 - symptomatic form of hemochromatosis type 1)  - In some cases, it might be appropriate to include the term as a narrow concept of a Mondo term (e.g. Orphanet:206634-Genetic skeletal muscle disease _MONDO:mondoIsBroaderThanSource_ MONDO:0020120-skeletal muscle disease ; Orphanet:498491 - Complete hemimelia _MONDO:mondoIsBroaderThanSource_ MONDO:0016240-hemimelia) | Orphanet:519323 - Syndromic macular dystrophy MONDO:0015879 - obsolete non-syndromic diaphragmatic or thoracic malformation                                                                                                                                                                                                  |                                    FALSE                                    |
| --------- MONDO:excludeGroupingModifierRare | grouping based on rare clinical modifier                 | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on shared modifier "rare".                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          | - Terms excluded with this code represent grouping terms; actual diseases including the modifier should not be excluded (e.g. Orphanet:102002 - Rare ataxia)  - In some cases, it might be appropriate to include the term as a narrow concept of a Mondo term (e.g. Orphanet:519298-Rare scleral disorder _MONDO:mondoIsBroaderThanSource_ MONDO:0001269-scleral disorder)                                                                                                                                                 | MONDO:0035001 - obsolete rare disorder of the visual organs                                                                                                                                                                                                                                                                  |                                    FALSE                                    |
| --- MONDO:excludeGroupingPopulation         | grouping based on individual or population of individual | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on affected individual or population of individual.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | Orphanet:91127 - Adenovirus infection in immunocompromised patients Orphanet:231080 - High-grade dysplasia in patients with Barrett esophagus                                                                                                                                                                                |                                    FALSE                                    |
| --- MONDO:excludeGroupingHeritability       | grouping based on heritability                           | Code used when the term is excluded from Mondo based on the fact that this term is not a specific disease; it instead groups diseases based on their heritability feature.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | When requested by the expert community, terms grouping diseases based on the heritability type could be included into Mondo. However (1) use case(s) for this request is(are) required (since other avenues, such as query through disease annotations, might be more appropriate solutions), (2) commitment by the requesters to maintain the list of grouped diseases (ie children of the grouping term) is requested in order to ensure that this ontology branch is correct and complete.                               | MONDO:0019601 - obsolete autosomal recessive axonal hereditary motor and sensory neuropathy                                                                                                                                                                                                                                  |                                    FALSE                                    |
| MONDO:excludeSpeciesoutofscope       | species out of scope                           | CCode used when the term is excluded from Mondo based on the fact that this term refer to a disease affecting a species which is out of scope for Mondo.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | Terms with this code can be added upon request.                               | NCIT:135001 - Turtle Neoplasm NCIT:134955 - Bat Skin Tumor                                                                                                                                                                                                                                  |                                    TRUE                                    |
